@@ -210,8 +210,8 @@ def logger(logFile, logMsg, printLogMsg):
     Logger for calling program. 
     
     Parameters: 
-    logFile (str): File to be logged to
-    logMsg (str): Message to be logged
+    logFile (str): File to be logged to\n
+    logMsg (str): Message to be logged\n
     printLogMsg (bool): Option to print log message
   
     Returns: 
@@ -223,6 +223,4 @@ def logger(logFile, logMsg, printLogMsg):
 
     program = sys.argv[0]
     program = program.rsplit('/', 1)[-1]
-    logFile.write('\n' + str(program) + " " + str(times()['day'][:3]) + " " + str(times()['month'][:3]) + " " + str(times()['date']) + " " + str(time.tzname[0]) + " " + str(times()['year']) + " - " + str(logMsg) + "\n")
-
-    # logFile.write('\n' + sys.argv[0] + " " + times()['day'][:3] + " " + times()['month'][:3] + " " + times()['date'] + " " + time.tzname[0] + " " + times()['year'] + " - " + str(logMsg + "\n")
\ No newline at end of file
+    logFile.write('\n' + str(program) + " " + str(times()['day'][:3]) + " " + str(times()['month'][:3]) + " " + str(times()['date']) + " " + str(time.tzname[0]) + " " + str(times()['year']) + " - " + str(logMsg) + "\n")
\ No newline at end of file
